==> FEMoctave-2.1.5.tar.gz: FEMoctave-v.2.1.5/README.md <==
# FEMoctave: a simple FEM package to use FEM for solving scalar and elasticity boundary value problems in one or two space dimensions

## CONTENTS:

1. HISTORY
2. PURPOSE
3. INSTALLATION INSTRUCTIONS
4. DOCUMENTATION, DEMOS AND EXAMPLES

## 1. HISTORY
The first version of FEMoctave was written in 2000.

In 2020 a major new version was generated.

In 2022 a major update is available.

In 2023 elasticity problems can be solved, plane stress, plane strain and axially symmetric setups.

In April 2023 algorithms for 1D problems are available.

In July 2023 a first algorithm for nonlinear, static 1D problems is available.

In August 2023 the algorithm for nonlinear, static 1D problems is improved and many examples provided

In October 2023 elementary Hertz contact problems provided

## 2. PURPOSE
The main goal is to provide a tool using Octave only to teach the method of finite elements, short FEM.
The mathematics of the algorithms are spelled out and implemented in Octave

## 3. INSTALLATION INSTRUCTIONS
To use all features of FEMoctave you have to install triangle.
Find instructions on how to intstall on a Linux system in FEMdoc.pdf.
Find the source code of Triangle and instructions at
https://www.cs.cmu.edu/~quake/triangle.html

## 4. DOCUMENTATION, DEMOS AND EXAMPLES
The subdirectories doc contain many sample codes, documented in doc/FEMdoc.pdf .

In section 3 of FEMdoc.pdf short demos are shown, one of each type.
The subdirectory doc/Demos contains the codes.

In section 9 of FEMdoc.pdf many examples are given.
The subdirectory doc/Examples contains the codes.

With best regards

Andreas Stahel

==> FEMoctave-2.1.8.tar.gz: FEMoctave-v.2.1.8/README.md <==
# FEMoctave: a simple FEM package to use FEM for solving scalar and elasticity boundary value problems in one or two space dimensions

## CONTENTS:

1. HISTORY
2. PURPOSE
3. INSTALLATION INSTRUCTIONS
4. DOCUMENTATION, DEMOS AND EXAMPLES

## 1. HISTORY
The first version of FEMoctave was written in 2000.

In 2020 a major new version was generated.

In 2022 a major update is available.

In 2023 elasticity problems can be solved, plane stress, plane strain and axially symmetric setups.

In April 2023 algorithms for 1D problems are available.

In July 2023 a first algorithm for nonlinear, static 1D problems is available.

In August 2023 the algorithm for nonlinear, static 1D problems is improved and many examples provided

In October 2023 elementary Hertz contact problems provided

In February 2025 equations with non isotropic or with complex coefficients can be solved

## 2. PURPOSE
The main goal is to provide a tool using Octave only to teach the method of finite elements, short FEM.
The mathematics of the algorithms are spelled out and implemented in Octave

## 3. INSTALLATION INSTRUCTIONS
To use all features of FEMoctave you have to install triangle.
Find instructions on how to intstall on a Linux system in FEMdoc.pdf.
Find the source code of Triangle and instructions at
https://www.cs.cmu.edu/~quake/triangle.html

## 4. DOCUMENTATION, DEMOS AND EXAMPLES
The subdirectories doc contain many sample codes, documented in doc/FEMdoc.pdf .

In section 3 of FEMdoc.pdf short demos are shown, one of each type.
The subdirectory doc/Demos contains the codes.

In section 9 of FEMdoc.pdf many examples are given.
The subdirectories doc/Examples contain the codes.

With best regards

Andreas Stahel
